# <div align="center">⚽ pyholdsport</div>

<div align="center">
    <kbd>
        <a href="https://github.com/daniel-mizsak/pyholdsport/actions/workflows/ci.yml" target="_blank"><img src="https://github.com/daniel-mizsak/pyholdsport/actions/workflows/ci.yml/badge.svg" alt="build status"></a>
        <a href="https://codecov.io/gh/daniel-mizsak/pyholdsport" target="_blank"><img src="https://codecov.io/gh/daniel-mizsak/pyholdsport/graph/badge.svg?token=KOC70X9YY0" alt="codecov"></a>
        <a href="https://results.pre-commit.ci/latest/github/daniel-mizsak/pyholdsport/main" target="_blank"><img src="https://results.pre-commit.ci/badge/github/daniel-mizsak/pyholdsport/main.svg" alt="pre-commit.ci status"></a>
        <a href="https://img.shields.io/github/license/daniel-mizsak/pyholdsport" target="_blank"><img src="https://img.shields.io/github/license/daniel-mizsak/pyholdsport" alt="license"></a>
    </kbd>
</div>

## Overview

Unofficial python library for interacting with holdsport.

## Getting started

Documentation is available at the [GitHub Pages of this repository](https://daniel-mizsak.github.io/pyholdsport).

<hr>

<div align="center">
    <strong>⭐ Star the repository if you found it useful ⭐</strong>
    <br>
    <a href="https://github.com/daniel-mizsak/repository-template" target="_blank">Repository Template</a> |
    <a href="https://github.com/daniel-mizsak/workflows" target="_blank">Reusable Workflows</a> |
    <a href="https://github.com/daniel-mizsak/mtjd" target="_blank">Development Environment </a>
</div>
